Crate windows_ccd

Crate windows_ccd 

Provides some convenience utilities for the Windows CCD API methods and types used via the windows crate.

Cargo Feature

When the dump feature is active, each Windows CCD API function call also generates a dump-*.json file containing the inputs and outputs of the call.

References

Modules

util
Convenience extension methods traits and functions.
windows
Re-exported types and values from the windows crate.

Structs

DeviceId
A convenience type to obtain and pass a display device adapterId and id.
Error
Error type for this crate.
Win32Error
A WIN32_ERROR wrapper.

Traits

GetDeviceInfo
A trait for the structures that can be returned by the display_config_get_device_info function.

Functions

display_config_get_device_info
Convenience function for the DisplayConfigGetDeviceInfo function.
query_display_config
Convenience function for the QueryDisplayConfig function.
set_display_config
Convenience function for the SetDisplayConfig function.

Type Aliases

Result
Result type for this crate.