Provides some convenience utilities for the Windows CCD API methods and types used via the windows crate.
Cargo Feature
When the dump feature is active, each Windows CCD API function call also generates a dump-*.json file containing the inputs and outputs of the call.
References
- The
windowscrate - Windows CCD API functions:
Modules
- util
- Convenience extension methods traits and functions.
- windows
- Re-exported types and values from the
windowscrate.
Structs
- Device
Id - A convenience type to obtain and pass a display device
adapterIdandid. - Error
- Error type for this crate.
- Win32
Error - A
WIN32_ERRORwrapper.
Traits
- GetDevice
Info - A trait for the structures that can be returned by the
display_config_get_device_infofunction.
Functions
- display_
config_ get_ device_ info - Convenience function for the DisplayConfigGetDeviceInfo function.
- query_
display_ config - Convenience function for the QueryDisplayConfig function.
- set_
display_ config - Convenience function for the SetDisplayConfig function.
Type Aliases
- Result
- Result type for this crate.